import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import { Cell, Tag } from '@antmjs/vantui';
import Page from '@/layouts/index';
import PowerList from '@/components/PowerList';
import { getTaCheckItem } from '@/services/tacheckitem';
import { ROLE_INSPECTOR } from '@/utils/user';

export default (props) => {

  const router = Taro.useRouter();
  const { checkId } = router.params;

  const [loading, setLoading] = React.useState(false);

  const params = React.useMemo(() => ({
    checkId,
    itemType: 'loc',
    pageSize: 100,
    mustValid: true,
  }), [checkId]);

  const onClick = (item) => {
    Taro.navigateTo({
      url: `/pages/check/edit/index?id=${item.itemId}&typ=${item.itemType}`
    })
  }
  
  return (
    <Page loading={loading} roles={[ROLE_INSPECTOR]}>
      <PowerList
        request={getTaCheckItem}
        params={params}
        renderItem={item => (
          <Cell
            isLink
            key={item.itemId}
            title={item.name}
            onClick={() => onClick(item)}
          >
            {
              item.readonly ? <Tag color="var(--main-bg-color)">已答完</Tag> : null
            }
          </Cell>
        )}
        onLoadingChange={setLoading}
      />
    </Page>
  )
}
